@@ -96,7 +96,7 @@ dglm <- function(formula = formula(data),
       1,dformula[2],dformula[3])
 #
 #   Evaluate the model frame and extract components
-   mframe <- eval(mcall, sys.parent())
+   mframe <<- eval(mcall, sys.parent())
    dterms <- attr(mframe, "terms")
    Z <- model.matrix(dterms, mframe, contrasts)
    doffset <- model.extract(mframe, offset)
@@ -114,7 +114,8 @@ dglm <- function(formula = formula(data),
       if(is.call(name.dlink))  # power link
          name.dlink <- deparse(name.dlink)
    }
-   if(!is.null(dlink$name))   name.dlink <- dlink$name
+   cat(">>>>>>>>dlink=",dlink,"\n")
+   if(!is.null(name.dlink))   name.dlink <- name.dlink
 #
 #   Construct the dispersion variance function
    if ( family$family=="Tweedie") {
@@ -522,7 +523,7 @@ print.summary.dglm <- function(x, ..., digits = NULL, quote = TRUE, prefix = "",
          ll <- lower.tri(correl)
          correl[ll] <- format(round(correl[ll], digits))
          correl[!ll] <- ""
-         print(correl[-1,  - p, drop = F], quote = F, digits = digits)
+         print(correl[-1,  - p, drop = FALSE], quote = FALSE, digits = digits)
       }
    }
 #
@@ -581,7 +582,7 @@ print.summary.dglm <- function(x, ..., digits = NULL, quote = TRUE, prefix = "",
          ll <- lower.tri(correl)
          correl[ll] <- format(round(correl[ll], digits))
          correl[!ll] <- ""
-         print(correl[-1,  - p, drop = F], quote = F, digits = digits)
+         print(correl[-1,  - p, drop = FALSE], quote = FALSE, digits = digits)
       }
    }
 #
